==> jc-1.4.0.tar.gz: java/awt/event/HierarchyEvent.h <==
// public class java.awt.event.HierarchyEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eb2011f6f1ec217f java_awt_event_HierarchyEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_HierarchyEvent_H_
#define _JC_java_awt_event_HierarchyEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_HierarchyEvent$sub_refs	_jc_java_awt_event_HierarchyEvent$sub_refs;
typedef struct _jc_java_awt_event_HierarchyEvent$sub_nonrefs	_jc_java_awt_event_HierarchyEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_HierarchyEvent$refs	_jc_java_awt_event_HierarchyEvent$refs;
typedef struct _jc_java_awt_event_HierarchyEvent$nonrefs	_jc_java_awt_event_HierarchyEvent$nonrefs;
typedef struct _jc_java_awt_event_HierarchyEvent$object	_jc_java_awt_event_HierarchyEvent$object;

typedef struct _jc_java_awt_event_HierarchyEvent$fields_struct	_jc_java_awt_event_HierarchyEvent$fields_struct;
typedef const struct _jc_java_awt_event_HierarchyEvent$vmethods	_jc_java_awt_event_HierarchyEvent$vmethods;
typedef const struct _jc_java_awt_event_HierarchyEvent$vtable	_jc_java_awt_event_HierarchyEvent$vtable;
typedef const struct _jc_java_awt_event_HierarchyEvent$vtype	_jc_java_awt_event_HierarchyEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_HierarchyEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ANCESTOR__5fMOVED;
	jint	ANCESTOR__5fRESIZED;
	jint	DISPLAYABILITY__5fCHANGED;
	jint	HIERARCHY__5fCHANGED;
	jint	HIERARCHY__5fFIRST;
	jint	HIERARCHY__5fLAST;
	jint	PARENT__5fCHANGED;
	jint	SHOWING__5fCHANGED;
};
extern _jc_java_awt_event_HierarchyEvent$fields_struct _jc_java_awt_event_HierarchyEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_HierarchyEvent$method$_init$1684d2f8ff0eb183(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Container$object *);
extern void _jc_java_awt_event_HierarchyEvent$method$_init$46538d1823d02968(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Container$object *, jlong);

// Virtual methods
extern jlong _jc_java_awt_event_HierarchyEvent$method$getChangeFlags$a16bff96fd3ec11d(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_HierarchyEvent$method$getChanged$ff6198deab4a3054(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
extern struct _jc_java_awt_Container$object *_jc_java_awt_event_HierarchyEvent$method$getChangedParent$4fd646f823ab4a2a(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_HierarchyEvent$method$getComponent$c7b7faa3c34ca595(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_HierarchyEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChangeFlags$a16bff96fd3ec11d;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChanged$ff6198deab4a3054;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChangedParent$4fd646f823ab4a2a;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getComponent$c7b7faa3c34ca595;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_HierarchyEvent$vmethods {
	jlong	(*getChangeFlags$a16bff96fd3ec11d)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
	struct _jc_java_awt_Component$object	*(*getChanged$ff6198deab4a3054)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
	struct _jc_java_awt_Container$object	*(*getChangedParent$4fd646f823ab4a2a)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
	struct _jc_java_awt_Component$object	*(*getComponent$c7b7faa3c34ca595)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *);
};

// Vtable
struct _jc_java_awt_event_HierarchyEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_HierarchyEvent$vmethods	java_awt_event_HierarchyEvent;
};

// Vtype
struct _jc_java_awt_event_HierarchyEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_HierarchyEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyEvent$sub_refs {
	struct _jc_java_awt_Component$object	*changed;
	struct _jc_java_awt_Container$object	*changedParent;
};

// Reference instance fields (object)
struct _jc_java_awt_event_HierarchyEvent$refs {
    _jc_java_awt_event_HierarchyEvent$sub_refs	java_awt_event_HierarchyEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyEvent$sub_nonrefs {
	jlong	changeFlags;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_HierarchyEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_HierarchyEvent$sub_nonrefs	java_awt_event_HierarchyEvent;
};

// Object instance structure
struct _jc_java_awt_event_HierarchyEvent$object {
	_jc_java_awt_event_HierarchyEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_HierarchyEvent$vtype	*vtype;
	_jc_java_awt_event_HierarchyEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_HierarchyEvent$vtype _jc_java_awt_event_HierarchyEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_HierarchyEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_HierarchyEvent$class_object;

#endif	/* _JC_java_awt_event_HierarchyEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/HierarchyEvent.h <==
// public class java.awt.event.HierarchyEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eb2011f6f1ec217f java_awt_event_HierarchyEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_HierarchyEvent_H_
#define _JC_java_awt_event_HierarchyEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_HierarchyEvent$sub_refs	_jc_java_awt_event_HierarchyEvent$sub_refs;
typedef struct _jc_java_awt_event_HierarchyEvent$sub_nonrefs	_jc_java_awt_event_HierarchyEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_HierarchyEvent$refs	_jc_java_awt_event_HierarchyEvent$refs;
typedef struct _jc_java_awt_event_HierarchyEvent$nonrefs	_jc_java_awt_event_HierarchyEvent$nonrefs;
typedef struct _jc_java_awt_event_HierarchyEvent$object	_jc_java_awt_event_HierarchyEvent$object;

typedef struct _jc_java_awt_event_HierarchyEvent$fields_struct	_jc_java_awt_event_HierarchyEvent$fields_struct;
typedef const struct _jc_java_awt_event_HierarchyEvent$vmethods	_jc_java_awt_event_HierarchyEvent$vmethods;
typedef const struct _jc_java_awt_event_HierarchyEvent$vtable	_jc_java_awt_event_HierarchyEvent$vtable;
typedef const struct _jc_java_awt_event_HierarchyEvent$vtype	_jc_java_awt_event_HierarchyEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_HierarchyEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ANCESTOR__5fMOVED;
	jint	ANCESTOR__5fRESIZED;
	jint	DISPLAYABILITY__5fCHANGED;
	jint	HIERARCHY__5fCHANGED;
	jint	HIERARCHY__5fFIRST;
	jint	HIERARCHY__5fLAST;
	jint	PARENT__5fCHANGED;
	jint	SHOWING__5fCHANGED;
};
extern _jc_java_awt_event_HierarchyEvent$fields_struct _jc_java_awt_event_HierarchyEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_HierarchyEvent$method$_init$1684d2f8ff0eb183(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_HierarchyEvent$method$_init$46538d1823d02968(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Container$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jlong _jc_java_awt_event_HierarchyEvent$method$getChangeFlags$a16bff96fd3ec11d(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_HierarchyEvent$method$getChanged$ff6198deab4a3054(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Container$object *_jc_java_awt_event_HierarchyEvent$method$getChangedParent$4fd646f823ab4a2a(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_HierarchyEvent$method$getComponent$c7b7faa3c34ca595(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_HierarchyEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChangeFlags$a16bff96fd3ec11d;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChanged$ff6198deab4a3054;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getChangedParent$4fd646f823ab4a2a;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$getComponent$c7b7faa3c34ca595;
extern _jc_method _jc_java_awt_event_HierarchyEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_HierarchyEvent$vmethods {
	jlong	(*getChangeFlags$a16bff96fd3ec11d)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Component$object	*(*getChanged$ff6198deab4a3054)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Container$object	*(*getChangedParent$4fd646f823ab4a2a)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Component$object	*(*getComponent$c7b7faa3c34ca595)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_HierarchyEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_HierarchyEvent$vmethods	java_awt_event_HierarchyEvent;
};

// Vtype
struct _jc_java_awt_event_HierarchyEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_HierarchyEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyEvent$sub_refs {
	struct _jc_java_awt_Component$object	*changed;
	struct _jc_java_awt_Container$object	*changedParent;
};

// Reference instance fields (object)
struct _jc_java_awt_event_HierarchyEvent$refs {
    _jc_java_awt_event_HierarchyEvent$sub_refs	java_awt_event_HierarchyEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyEvent$sub_nonrefs {
	jlong	changeFlags;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_HierarchyEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_HierarchyEvent$sub_nonrefs	java_awt_event_HierarchyEvent;
};

// Object instance structure
struct _jc_java_awt_event_HierarchyEvent$object {
	_jc_java_awt_event_HierarchyEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_HierarchyEvent$vtype	*vtype;
	_jc_java_awt_event_HierarchyEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_HierarchyEvent$vtype _jc_java_awt_event_HierarchyEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_HierarchyEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_HierarchyEvent$class_object;

#endif	/* _JC_java_awt_event_HierarchyEvent_H_ */
